@@ -60,7 +60,14 @@ struct _GKMKeyringEditorClass
   GObjectClass parent;
 };
 
-GType gkm_keyring_editor_get_type (void);
+typedef void (*GKMKeyringEditorGetAttributesCallback) (gpointer                   user_data,
+						       GnomeKeyringItemType       item_type,
+						       GnomeKeyringAttributeList *attributes);
+
+typedef void (*GKMKeyringEditorGetAclCallback) (gpointer  user_data,
+						GSList   *acl);
+
+G_GNUC_CONST GType gkm_keyring_editor_get_type (void);
 
 GObject *gkm_keyring_editor_new (const gchar *keyring_name);
 
@@ -70,15 +77,33 @@ void gkm_keyring_editor_set_keyring_name   (GKMKeyringEditor *self,
 					    const gchar      *keyring_name);
 gchar *gkm_keyring_editor_get_keyring_name (GKMKeyringEditor *self);
 
-typedef void (*GKMKeyringEditorGetAttributesCallback) (gpointer                   user_data,
-						       GnomeKeyringItemType       item_type,
-						       GnomeKeyringAttributeList *attributes);
+
+void gkm_keyring_editor_set_key_name        (GKMKeyringEditor *self,
+				             GtkTreeIter       iter,
+				             const gchar      *new_name);
+
+void gkm_keyring_editor_set_key_secret      (GKMKeyringEditor *self,
+				             GtkTreeIter       iter,
+				             const gchar      *new_secret);
 
 void gkm_keyring_editor_get_attributes_list (GKMKeyringEditor *self,
 					     GtkTreeIter       iter,
 					     GKMKeyringEditorGetAttributesCallback callback,
 					     gpointer          user_data);
 
+void gkm_keyring_editor_set_attributes_list (GKMKeyringEditor *self,
+				             GtkTreeIter       iter,
+				             GnomeKeyringAttributeList *attributes);
+
+void gkm_keyring_editor_get_acl (GKMKeyringEditor *self,
+				 GtkTreeIter       iter,
+				 GKMKeyringEditorGetAclCallback callback,
+				 gpointer          user_data);
+
+void gkm_keyring_editor_set_acl (GKMKeyringEditor *self,
+				 GtkTreeIter       iter,
+				 GList            *acl);
+
 void gkm_keyring_editor_delete_key          (GKMKeyringEditor *self,
 			                     GtkTreeIter       iter);
 
